==> nextcloud-23.0.9.tgz: nextcloud/apps/circles/l10n/pt_PT.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Ficheiros de Círculos",
    "Select circles to filter by" : "Selecione círculos para filtrar por",
    "No circles found" : "Não foram encontrados círculos",
    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
    "You created the circle {circle}" : "Criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You deleted {circle}" : "Eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You linked {group} to {circle}" : "Associou {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
    "You joined {circle}" : "Juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se a {circle}",
    "You left {circle}" : "Saiu de {circle}",
    "{member} left {circle}" : "{member} saiu de {circle}",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Hidden" : "Escondido",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federada",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s partilhou »%s« consigo.",
    "%s on %s" : "%s às %s",
    "Password to access »%1$s« shared to you by %2$s" : "Palavra passe para aceder »%1$s« partilhado por si %2$s",
    "Password to access »%s«" : "Palavra-chave de acesso »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte palavra-chave:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo não encontrado",
    "A circle with that name exists" : "Já existe um círculo com esse nome",
    "You cannot join this circle" : "Não pode juntar-se a este círculo",
    "This member is not a moderator" : "Este membro não é um moderador",
    "Insufficient privileges" : "Privilégios insuficientes",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "You are already a member of this circle" : "Já é um membro deste círculo",
    "You have been blocked from this circle" : "Foi bloqueado neste círculo",
    "The user is already a member of this circle" : "O utilizador já é membro deste círculo",
    "The user has already been invited into this circle" : "O utilizador já foi convidado para este círculo",
    "Accept" : "Aceitar",
    "%s" : "%s",
    "Personal Circle" : "Círculo Pessoal",
    "now" : "agora",
    "This user does not exist" : "Este utilizador não existe",
    "Email format is not valid" : "O formato de e-mail não é válido",
    "This contact is not available" : "Este contacto não está disponível",
    "Could not find share" : "Não foi possível encontrar a partilha",
    "No files in here" : "Sem ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.4.tgz: nextcloud/apps/circles/l10n/pt_PT.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Ficheiros de Círculos",
    "Select circles to filter by" : "Selecione círculos para filtrar por",
    "No circles found" : "Não foram encontrados círculos",
    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
    "You created the circle {circle}" : "Criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You deleted {circle}" : "Eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You linked {group} to {circle}" : "Associou {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
    "You joined {circle}" : "Juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se a {circle}",
    "You left {circle}" : "Saiu de {circle}",
    "{member} left {circle}" : "{member} saiu de {circle}",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Hidden" : "Escondido",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federada",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s partilhou »%s« consigo.",
    "%s on %s" : "%s às %s",
    "Password to access »%1$s« shared to you by %2$s" : "Palavra passe para aceder »%1$s« partilhado por si %2$s",
    "Password to access »%s«" : "Palavra-chave de acesso »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte palavra-chave:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo não encontrado",
    "You cannot join this circle" : "Não pode juntar-se a este círculo",
    "This member is not a moderator" : "Este membro não é um moderador",
    "Insufficient privileges" : "Privilégios insuficientes",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "You are already a member of this circle" : "Já é um membro deste círculo",
    "You have been blocked from this circle" : "Foi bloqueado neste círculo",
    "Accept" : "Aceitar",
    "%s" : "%s",
    "Personal Circle" : "Círculo Pessoal",
    "A circle with that name exists" : "Já existe um círculo com esse nome",
    "now" : "agora",
    "Email format is not valid" : "O formato de e-mail não é válido",
    "This contact is not available" : "Este contacto não está disponível",
    "No files in here" : "Sem ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "The user is already a member of this circle" : "O utilizador já é membro deste círculo",
    "The user has already been invited into this circle" : "O utilizador já foi convidado para este círculo",
    "This user does not exist" : "Este utilizador não existe",
    "Could not find share" : "Não foi possível encontrar a partilha"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
